Glossary - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Glossary

plugin

  A drop-in piece of functionality.

  A plugin is a concrete class that extends `betty.plugin.Plugin`.

  Read more about plugins.

plugin instance

  An object that is an instance of a plugin (class).

  Read more about plugins.

plugin type

  A plugin type is a potentially abstract class that is or extends `betty.plugin.Plugin`.

  Read more about plugins.

static site

  A website that consists solely of prebuilt files that are served to visitors directly as they are. Read more about static web pages on Wikipedia

static site generator

  A software application that builds static sites. Read more about static site generators on Wikipedia